@@ -27,15 +27,22 @@ class Book:
 
         Books can be one of 2 types:
             1) a git repo
-            2) a symlink to another location
+            2) a symlink to another location (absolute or relative, absolute
+               paths are decomposed to relative to allow for portability of
+               built kits
 
         Keyword arguments:
-            path -- absolute or relative path to the location the repo should be in
-            git -- git url to be used as the source for the repo
-            branch -- branch/sha1/tag to be used in the checkout, defaults to master
-            link -- destination of the link target
-            skiprepourlcheck -- flag to skip that the git url matches the definition during status checks
-            fakeroot -- a gitshelf may specify absolute paths, setting fakeroot allows you to make an absolute path relative to the passed path
+            path:       absolute or relative path to the location the repo
+                        should be in
+            git:        git url to be used as the source for the repo
+            branch:     branch/sha1/tag to be used in the checkout, defaults
+                        to master
+            link:       destination of the link target
+            fakeroot:   a gitshelf may specify absolute paths, setting
+                        fakeroot allows you to make an absolute path
+                        relative to the passed path
+            skiprepourlcheck: flag to skip that the git url matches the
+                        definition during status checks
 
     """
 
@@ -131,6 +138,9 @@ class Book:
 
         cwd = os.getcwd()
         parent = os.path.dirname(self.path.rstrip(os.sep))
+        if parent == '' or parent is None:
+          parent = '.'
+        LOG.debug("parent directory for {0} is {1}".format(self.path, parent))
 
         if not os.path.islink(self.path):
             LOG.info("Creating book {0} via a link to {1}".format(self.path, self.link))
